#
# spec file for package python3-tox
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-tox
Version:        2.3.1
Release:        2.6
Summary:        Virtualenv-based automation of test activities
License:        MIT
Group:          Development/Languages/Python
Url:            https://bitbucket.org/hpk42/tox
Source:         https://files.pythonhosted.org/packages/source/t/tox/tox-%{version}.tar.gz
# PATCH-FIX-OPENSUSE speilicke@suse.com -- Due to update-alternative usage, some bianries aren't available at build-time
Patch0:         tox-disable-env-tests.patch
BuildRequires:  python3-devel
BuildRequires:  unzip
BuildRequires:  python3-pluggy
BuildRequires:  python3-py >= 1.4.17
BuildRequires:  python3-virtualenv >= 1.11.2
Requires:       python3-pluggy
Requires:       python3-py >= 1.4.17
Requires:       python3-virtualenv >= 1.11.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Tox as is a generic virtualenv management and test command line tool you can
use for:

* checking your package installs correctly with different
  Python versions and interpreters

* running your tests in each of the
  environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration
  servers, greatly reducing boilerplate and merging
  CI and shell-based testing.

%prep
%setup -q -n tox-%{version}
%patch0 -p1
sed -i -e "/^\\[testenv\\]/ a\\sitepackages = True" tox.ini
sed -i -e "s/tox=tox:cmdline/tox-%{py3_ver}=tox:cmdline/" \
       -e "s/tox-quickstart=tox._quickstart:main/tox-quickstart-%{py3_ver}=tox._quickstart:main/" setup.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for B in tox tox-quickstart ; do
  touch %{buildroot}%{_sysconfdir}/alternatives/$B
  ln -sf %{_sysconfdir}/alternatives/$B %{buildroot}/%{_bindir}/$B
done

%post
update-alternatives \
    --install %{_bindir}/tox tox %{_bindir}/tox-%{py3_ver} 30 \
    --slave %{_bindir}/tox-quickstart tox-quickstart %{_bindir}/tox-quickstart-%{py3_ver}

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove tox %{_bindir}/tox-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{_bindir}/tox
%{_bindir}/tox-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/tox
%{_bindir}/tox-quickstart
%{_bindir}/tox-quickstart-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/tox-quickstart
%{python3_sitelib}/tox-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/tox

%changelog
* Thu May 19 2016 toddrme2178@gmail.com
- Split documentation into own subpackage to speed up build.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Mon Dec 21 2015 arun@gmx.de
- update to version 2.3.1:
  * fix issue294: re-allow cross-section substitution for setenv.
* Sun Dec 13 2015 arun@gmx.de
- update to version 2.3.0:
  * DEPRECATE use of "indexservers" in tox.ini. It complicates the
    internal code and it is recommended to rather use the
    devpi system for managing indexes for pip.
  * fix issue285: make setenv processing fully lazy to fix regressions
    of tox-2.2.X and so that we can now have testenv attributes like
    "basepython" depend on environment variables that are set in a
    setenv section. Thanks Nelfin for some tests and initial work on a
    PR.
  * allow "#" in commands.  This is slightly incompatible with
    commands sections that used a comment after a "\" line
    continuation. Thanks David Stanek for the PR.
  * fix issue289: fix build_sphinx target, thanks Barry Warsaw.
  * fix issue252: allow environment names with special characters.
    Thanks Julien Castets for initial PR and patience.
  * introduce experimental tox_testenv_create(venv, action) and
    tox_testenv_install_deps(venv, action) hooks to allow plugins to
    do additional work on creation or installing deps.  These hooks
    are experimental mainly because of the involved "venv" and session
    objects whose current public API is not fully guranteed.
  * internal: push some optional object creation into tests because
    tox core doesn't need it.
* Sat Nov 14 2015 arun@gmx.de
- update to version 2.2.1:
  * fix bug where {envdir} substitution could not be used in setenv if
    that env value is then used in {basepython}. Thanks Florian
    Bruhin.
- changes from version 2.2.0:
  * fix issue265 and add LD_LIBRARY_PATH to passenv on linux by
    default because otherwise the python interpreter might not start
    up in certain configurations (redhat software collections).
    Thanks David Riddle.
  * fix issue246: fix regression in config parsing by reordering such
    that {envbindir} can be used again in tox.ini. Thanks Olli Walsh.
  * fix issue99: the {env:...} substitution now properly uses
    environment settings from the "setenv" section. Thanks Itxaka
    Serrano.
  * fix issue281: make --force-deps work when urls are present in
    dependency configs.  Thanks Glyph Lefkowitz for reporting.
  * fix issue174: add new "ignore_outcome" testenv attribute which can
    be set to True in which case it will produce a warning instead of
    an error on a failed testenv command outcome.  Thanks Rebecka
    Gulliksson for the PR.
  * fix issue280: properly skip missing interpreter if
    {envsitepackagesdir} is present in commands. Thanks BB:ceridwenv
* Fri Aug 14 2015 p.drouand@gmail.com
- Update to version 2.1.1
  * fix platform skipping for detox
  * report skipped platforms as skips in the summary
- Fix build on Factory
- Disable tests for now; require network
* Sun Jun 21 2015 arun@gmx.de
- patch:
  * updated patch
- update to version 2.1.0:
  * fix issue258, fix issue248, fix issue253: for non-test commands
  (installation, venv creation) we pass in the full invocation
  environment.
  * remove experimental --set-home option which was hardly used and
    hackily implemented (if people want home-directory isolation we
    should figure out a better way to do it, possibly through a
    plugin)
  * fix issue259: passenv is now a line-list which allows to
    intersperse comments.  Thanks stefano-m.
  * allow envlist to be a multi-line list, to intersperse comments and
    have long envlist settings split more naturally.  Thanks Andre
    Caron.
  * introduce a TOX_TESTENV_PASSENV setting which is honored when
    constructing the set of environment variables for test
    environments.  Thanks Marc Abramowitz for pushing in this
    direction.
* Fri Jun  5 2015 arun@gmx.de
- update to version 2.0.2:
  * fix issue247: tox now passes the LANG variable from the tox invocation
    environment to the test environment by default.
  * add SYSTEMDRIVE into default passenv on windows to allow pip6 to work.
    Thanks Michael Krause.
* Sun May 24 2015 arun@gmx.de
- specfile:
  * added pluggy requirement
  * updated patch file
- update to version 2.0.1:
  * fix wheel packaging to properly require argparse on py26.
- changes from version 2.0.0:
  * (new) introduce environment variable isolation:
    tox now only passes the PATH and PIP_INDEX_URL variable from the
    tox invocation environment to the test environment and on Windows
    also "SYSTEMROOT", "PATHEXT", "TEMP" and "TMP" whereas on
    unix additionally "TMPDIR" is passed.  If you need to pass
    through further environment variables you can use the new
    "passenv" setting, a space-separated list of environment
    variable names.  Each name can make use of fnmatch-style glob
    patterns.  All environment variables which exist in the
    tox-invocation environment will be copied to the test environment.
  * a new "--help-ini" option shows all possible testenv settings and
    their defaults.
  * (new) introduce a way to specify on which platform a
    testenvironment is to execute: the new per-venv "platform" setting
    allows to specify a regular expression which is matched against
    sys.platform.  If platform is set and doesn't match the platform
    spec in the test environment the test environment is ignored, no
    setup or tests are attempted.
  * (new) add per-venv "ignore_errors" setting, which defaults to
    False.  If "True", a non-zero exit code from one command will be
    ignored and further commands will be executed (which was the
    default behavior in tox < 2.0).  If "False" (the default), then a
    non-zero exit code from one command will abort execution of
    commands for that environment.
  * show and store in json the version dependency information for each
    venv
  * remove the long-deprecated "distribute" option as it has no effect
    these days.
  * fix issue233: avoid hanging with tox-setuptools integration
    example. Thanks simonb.
  * fix issue120: allow substitution for the commands section.  Thanks
    Volodymyr Vitvitski.
  * fix issue235: fix AttributeError with --installpkg.  Thanks
    Volodymyr Vitvitski.
  * tox has now somewhat pep8 clean code, thanks to Volodymyr
    Vitvitski.
  * fix issue240: allow to specify empty argument list without it
    being rewritten to ".".  Thanks Daniel Hahler.
  * introduce experimental (not much documented yet) plugin system
    based on pytest's externalized "pluggy" system.  See
    tox/hookspecs.py for the current hooks.
  * introduce parser.add_testenv_attribute() to register an
    ini-variable for testenv sections.  Can be used from plugins
    through the tox_add_option hook.
  * rename internal files -- tox offers no external API except for the
    experimental plugin hooks, use tox internals at your own risk.
  * DEPRECATE distshare in documentation
* Wed Mar 25 2015 arun@gmx.de
- specfile:
  * updated patch (line number change and removal of
    tests/test_z_cmdline.py)
- update to version 1.9.2:
  * backout ability that --force-deps substitutes name/versions in
    requirement files due to various issues.  This fixes issue228,
    fixes issue230, fixes issue231 which popped up with 1.9.1.
- changes from versrion 1.9.1:
  * use a file instead of a pipe for command output in
    "--result-json".  Fixes some termination issues with python2.6.
  * allow --force-deps to override dependencies in "-r" requirements
    files.  Thanks Sontek for the PR.
  * fix issue227: use "-m virtualenv" instead of "-mvirtualenv" to
    make it work with pyrun.  Thanks Marc-Andre Lemburg.
* Thu Feb 26 2015 arun@gmx.de
- update to version 1.9.0:
  * fix issue193: Remove "--pre" from the default "install_command";
    by default tox will now only install final releases from PyPI for
    unpinned dependencies. Use "pip_pre = true" in a testenv or the
    "--pre" command-line option to restore the previous behavior.
  * fix issue199: fill resultlog structure ahead of virtualenv
    creation
  * refine determination if we run from Jenkins, thanks Borge Lanes.
  * echo output to stdout when "--report-json" is used
  * fix issue11: add a "skip_install" per-testenv setting which
    prevents the installation of a package. Thanks Julian Krause.
  * fix issue124: ignore command exit codes; when a command has a "-"
    prefix, tox will ignore the exit code of that command
  * fix issue198: fix broken envlist settings,
    e.g. {py26,py27}{-lint,}
  * fix issue191: lessen factor-use checks
* Thu Jan  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * updated line numbers in patch file, updated patches
- update to version 1.8.1:
  * fix issue190: allow setenv to be empty.
  * allow escaping curly braces with "\".  Thanks Marc Abramowitz for the PR.
  * allow "." names in environment names such that "py27-django1.7" is a
    valid environment name.  Thanks Alex Gaynor and Alex Schepanovski.
  * report subprocess exit code when execution fails.  Thanks Marius
    Gedminas.
- change from version 1.8.0:
  * new multi-dimensional configuration support.  Many thanks to
    Alexander Schepanovski for the complete PR with docs.
    And to Mike Bayer and others for testing and feedback.
  * fix issue148: remove "__PYVENV_LAUNCHER__" from os.environ when starting
    subprocesses. Thanks Steven Myint.
  * fix issue152: set VIRTUAL_ENV when running test commands,
    thanks Florian Ludwig.
  * better report if we can't get version_info from an interpreter
    executable. Thanks Floris Bruynooghe.
- changes from version 1.7.2:
  * fix issue150: parse {posargs} more like we used to do it pre 1.7.0.
    The 1.7.0 behaviour broke a lot of OpenStack projects.
    See PR85 and the issue discussions for (far) more details, hopefully
    resulting in a more refined behaviour in the 1.8 series.
    And thanks to Clark Boylan for the PR.
  * fix issue59: add a config variable ``skip-missing-interpreters`` as well as
    command line option ``--skip-missing-interpreters`` which won't fail the
    build if Python interpreters listed in tox.ini are missing.  Thanks
    Alexandre Conrad for PR104.
  * fix issue164: better traceback info in case of failing test commands.
    Thanks Marc Abramowitz for PR92.
  * support optional env variable substitution, thanks Morgan Fainberg
    for PR86.
  * limit python hashseed to 1024 on Windows to prevent possible
    memory errors.  Thanks March Schlaich for the PR90.
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.7.1:
  - fix issue162: don't list python 2.5 as compatibiliy/supported
  - fix issue158 and fix issue155: windows/virtualenv properly works now:
    call virtualenv through "python -m virtualenv" with the same
    interpreter which invoked tox.  Thanks Chris Withers, Ionel Maries Cristian.
- Add tox-disable-env-tests.patch: Disable tests that need network-access
  and that depend on /usr/bin/tox (which is only added via u-a in %%post)
- Implement update-alternatives to allow parallel installtion with python-tox
* Thu Jul  3 2014 speilicke@suse.com
- Initial version
